@@ -9,6 +9,9 @@ import asyncio as _asyncio
 from typing import List as _List
 from typing import Optional as _Optional
 
+# third-party
+from vcorelib.asyncio import log_exceptions as _log_exceptions
+
 # internal
 from runtimepy.net.connection import Connection as _Connection
 
@@ -45,7 +48,7 @@ class ConnectionManager:
             )
 
             # Filter completed tasks out of the working set.
-            next_tasks = [x for x in tasks if not x.done()]
+            next_tasks = _log_exceptions(tasks)
 
             # Filter out disabled connections.
             conns = [x for x in conns if not x.disabled]
@@ -55,14 +58,13 @@ class ConnectionManager:
             if new_conn_task.done():
                 new_conn = new_conn_task.result()
                 conns.append(new_conn)
-                next_tasks.append(_asyncio.create_task(new_conn.process()))
+                next_tasks.append(
+                    _asyncio.create_task(new_conn.process(stop_sig=stop_sig))
+                )
                 new_conn_task = None
 
             # If the stop signal was sent, cancel existing connections.
             if stop_sig.is_set():
-                for conn in conns:
-                    conn.disable("application stop")
-
                 # Allow existing tasks to clean up.
                 if new_conn_task is not None:
                     new_conn_task.cancel()
